@@ -21,6 +21,8 @@ from .view import View, DefaultView
 class Piece(LoggedClass):
     """Wrapper around :class:`~.score.Score` for associating it with parsed TSV files"""
 
+    _deprecated_elements = ["get_dataframe"]
+
     def __init__(self, fname: str, view: View = None, logger_cfg={}, ms=None):
         super().__init__(subclass='Piece', logger_cfg=logger_cfg)
         self.name = fname
@@ -591,11 +593,6 @@ class Piece(LoggedClass):
         return [(file, score) for file, score in parsed_scores if score.mscx.changed]
 
 
-    def get_dataframe(self, *args, **kwargs) -> None:
-        """Deprecated method. Replaced by :meth:`get_parsed`, :meth:`extract_facet`, and :meth:`get_facet()`."""
-        raise AttributeError(f"Method not in use any more. Use _.get_parsed() to retrieve a parsed TSV file, "
-                             f"_.extract_facet() to retrieve a freshly extracted DataFrame, "
-                             f"or _.get_facet() to retrieve either, according to availability.")
 
 
     def get_facets(self,
@@ -977,7 +974,12 @@ class Piece(LoggedClass):
                 files = [selected]
             if n_unparsed > 0:
                 plural = 'files' if n_unparsed > 1 else 'file'
-                self.logger.debug(f"Disregarded {n_unparsed} unparsed {facet} {plural}. Set force=True to automatically parse.")
+                try:
+                    self.logger.debug(f"Disregarded {n_unparsed} unparsed {facet} {plural}. Set force=True to automatically parse.")
+                except AttributeError:
+                    if self.logger is None:
+                        raise RuntimeError("The logger is None. This happens when __getstate__ is called. Did you use copy()?")
+                    raise
             parsed_files = [(file, self._get_transformed_facet_at_ix(ix=file.ix, unfold=unfold, interval_index=interval_index)) for file in files if file.ix in self.ix2parsed]
             parsed_files = [(file, df) for file, df in parsed_files if df is not None]
             n_parsed = len(parsed_files)
@@ -1642,3 +1644,8 @@ class Piece(LoggedClass):
         return written_paths
 
 
+    def get_dataframe(self, *args, **kwargs) -> None:
+        """Deprecated method. Replaced by :meth:`get_parsed`, :meth:`extract_facet`, and :meth:`get_facet()`."""
+        raise DeprecationWarning(f"Method not in use any more. Use _.get_parsed() to retrieve a parsed TSV file, "
+                             f"_.extract_facet() to retrieve a freshly extracted DataFrame, "
+                             f"or _.get_facet() to retrieve either, according to availability.")
\ No newline at end of file
